%QSCAT_R_example_KATRINA.m -- plot example data from KATRINA (2005) file
%Purpose: makes two example plots: 1) time evolution of azimuthal wind
%profile; 2) snapshot of multiple data types

% Author: Dan Chavas
% CEE Dept, Princeton University
% email: drchavas@gmail.com
% Website: -
% 4 Sep 2014

%------------- BEGIN CODE --------------

clear
clc
close all

addpath mfiles

%% USER INPUT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ncfile_in = 'AL122005_KATRINA_2005236N23285.nc';
missing_value_flag = -9999;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Extract data from netcdf file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sprintf('Extracting data from %s',ncfile_in)

datadir_QS = './';
file_storm = ncfile_in;

variable_in = 'global';  %'global' mirrors '/', which accesses global variable
attribute_in = 'StormName';
[StormName] = nc_extract_att(datadir_QS,file_storm,variable_in,attribute_in);

variable_in = 'global';  %'global' mirrors '/', which accesses global variable
attribute_in = 'StormYear';
[StormYear] = nc_extract_att(datadir_QS,file_storm,variable_in,attribute_in);

variable_in = 'global';  %'global' mirrors '/', which accesses global variable
attribute_in = 'StormID_ATCF';
[StormID_ATCF] = nc_extract_att(datadir_QS,file_storm,variable_in,attribute_in);

variable_in = 'QS_PASS_timeoffset';
[QS_PASS_timeoffset] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_wind_speed_thresholds';
[QS_WR_wind_speed_thresholds] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_azimuthal_wind_speed';
[QS_WR_azimuthal_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_total_wind_speed';
[QS_WR_total_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_azimuthal_wind_speed_asymmetry_parameter';
[QS_WR_azimuthal_wind_speed_asymmetry_parameter] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_total_wind_speed_asymmetry_parameter';
[QS_WR_total_wind_speed_asymmetry_parameter] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_azimuthal_maximum_wind_speed_threshold';
[QS_WR_azimuthal_maximum_wind_speed_threshold] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_total_maximum_wind_speed_threshold';
[QS_WR_total_maximum_wind_speed_threshold] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_azimuthal_maximum_wind_speed';
[QS_WR_azimuthal_maximum_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_total_maximum_wind_speed';
[QS_WR_total_maximum_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_azimuthal_maximum_wind_speed_asymmetry_parameter';
[QS_WR_azimuthal_maximum_wind_speed_asymmetry_parameter] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_WR_total_maximum_wind_speed_asymmetry_parameter';
[QS_WR_total_maximum_wind_speed_asymmetry_parameter] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_date_time';
[QS_PASS_date_time] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_latitude';
[lat_center] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_longitude';
[lon_center] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_vmax';
[Vmax_BT] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_pmin';
[Pmin_BT] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_zonal_translation_speed';
[u_translation] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_PASS_meridional_translation_speed';
[v_translation] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_radius_coordinate';
[r_radprof] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_azimuthal_wind_speed';
[QS_RP_azimuthal_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_radial_wind_speed';
[QS_RP_radial_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_total_wind_speed';
[QS_RP_total_wind_speed] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_asymmetry_parameter';
[QS_RP_asymmetry_parameter] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_rainrate';
[QS_RP_rainrate] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_asymmetry_parameter_rainrate';
[QS_RP_asymmetry_parameter_rainrate] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_cloudssmi';
[QS_RP_cloudssmi] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

variable_in = 'QS_RP_asymmetry_parameter_cloud';
[QS_RP_asymmetry_parameter_cloud] = nc_extract_var(datadir_QS,file_storm,variable_in,missing_value_flag)';

num_times_QS = size(QS_PASS_date_time,1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Make a couple of plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sprintf('Plotting data from %s',ncfile_in)

set(0,'defaultaxesfontsize',12,'defaultaxesfontweight','normal',...
                'defaultlinelinewidth',1,'DefaultAxesFontName','Helvetica')
            
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FIGURE 1: EVOLUTION PLOT

%%INITIAL SETUP %%%%%%%%
hh=figure(1);
clf(hh)
set(hh,'units','centimeters');
hpos = [0 0 30 30];
set(hh,'Position',hpos);
set(hh,'PaperUnits','centimeters');
set(hh,'PaperPosition',hpos);
set(hh,'PaperSize',hpos(3:4));
set(gca,'position',[0.12    0.12    0.82    0.8]);

%%Radial profiles of azimuthal wind
clear hpl
for ff=1:num_times_QS
    hpl(ff) = plot(r_radprof/1000,QS_RP_azimuthal_wind_speed(ff,:),...
        'Color',[1 0 0]*(num_times_QS-ff)/(num_times_QS));
    hold on
    plot(QS_WR_azimuthal_wind_speed(ff,:)/1000,QS_WR_wind_speed_thresholds(ff,:),'x',...
        'Color',[0 1 0]*(num_times_QS-ff)/(num_times_QS),'MarkerSize',10);
end


%%Aesthetics
axis([0 1400 0 50])
input_title = sprintf('%s %s (%s): evolution',StormName,StormYear,StormID_ATCF);
title(input_title)
xlabel('radius [km]')
ylabel('azimuthal wind speed [m/s]')
legend(hpl,cellstr(num2str(QS_PASS_date_time)),'FontSize',14)
legend boxoff

%%Save plot
plot_filename = sprintf('QSCAT_R_example_KATRINA_evolution');
saveas(gcf,plot_filename,'pdf')
sprintf('Evolution plot saved as %s.pdf',plot_filename)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FIGURE 2: SNAPSHOT PLOT

%%INITIAL SETUP %%%%%%%%
hh=figure(2);
clf(hh)
set(hh,'units','centimeters');
hpos = [0 0 30 30];
set(hh,'Position',hpos);
set(hh,'PaperUnits','centimeters');
set(hh,'PaperPosition',hpos);
set(hh,'PaperSize',hpos(3:4));
set(gca,'position',[0.12    0.12    0.82    0.8]);

%%Choose case with highest intensity
i_plot = find(Vmax_BT==max(Vmax_BT),1);

%%Wind variables
plot(r_radprof/1000,QS_RP_total_wind_speed(i_plot,:),'k','LineWidth',2)
hold on
plot(r_radprof/1000,QS_RP_azimuthal_wind_speed(i_plot,:),'k--','LineWidth',2)
plot(r_radprof/1000,-QS_RP_radial_wind_speed(i_plot,:),'k:','LineWidth',2)

%%Rain
plot(r_radprof/1000,.1*QS_RP_rainrate(i_plot,:),'b')

%%Data asymmetry variables
plot(r_radprof/1000,10*QS_RP_asymmetry_parameter(i_plot,:),'y')
plot(r_radprof/1000,10*QS_RP_asymmetry_parameter_rainrate(i_plot,:),'Color',[.7 .7 0])

%%Wind radii
plot(QS_WR_azimuthal_wind_speed(i_plot,:)/1000,QS_WR_wind_speed_thresholds(i_plot,:),'x',...
        'Color',[0 .5 0],'MarkerSize',15,'MarkerFaceColor','b')
plot(QS_WR_total_wind_speed(i_plot,:)/1000,QS_WR_wind_speed_thresholds(i_plot,:),'x',...
        'Color',[0 .5 0],'MarkerSize',15,'MarkerFaceColor','b')


%%Aesthetics
legend({'Total wind','Azimuthal wind','Radial wind (*-1)','Rain rate (*.1)','Data asymmetry: wind (*10)','Data asymmetry: rain rate (*10)','Wind radii'})
legend boxoff
axis([0 1400 0 50])
input_title = sprintf('%s %s (%s): %s snapshot',StormName,StormYear,StormID_ATCF,QS_PASS_date_time(i_plot,:));
title(input_title)
xlabel('radius [km]')
ylabel('wind speed [m/s]; rain rate; data asymmetry')

%%Save plot
plot_filename = sprintf('QSCAT_R_example_KATRINA_snapshot');
saveas(gcf,plot_filename,'pdf')
sprintf('Snapshot plot saved as %s.pdf',plot_filename)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%------------- END OF CODE --------------